<?php
/*
Copyright (c) 2006 Rob Allen

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/


/**
 * Akrabat_Action allows us to tie up the view to the controller
 */

/** Zend_Controller_Action */
require_once 'Zend/Controller/Action.php';

abstract class Akrabat_Controller_Action extends Zend_Controller_Action
{
    private $assignedVars;
    protected $actionTemplate = null;

    /**
     * @var Zend_View
     */
    protected $view;

    function __construct()
    {
        $assignedVars = new StdClass();
        $this->view = Zend::registry('view');
    }

    /**
     * Assuming that we aren't using persistant controllers, the destructor
     * gets called after every action. Obviously the first time this is called
     * is for the first action which we'll consider to be the "master" action
     * and so assign it to "content"
     *
     */
    function __destruct()
    {
        $action = $this->_action->getActionName();
        $defaultActionTemplate = $this->_action->getControllerName() . DIRECTORY_SEPARATOR . $action . '.tpl.php';

        // assign the variables created by the controller to an array named after the action
        $this->view->assign($action, $this->assignedVars);

        // create a template for the action in $templates
        // consider the first action to be the main action and so assign it's template to
        // $templates['content']
        if(is_object($this->view->Templates))
        {
            $templates = $this->view->Templates;
        }
        else
        {
            $templates = new StdClass();
        }

        if(!isset($templates->content))
        {
            $templates->content = $this->actionTemplate ? $this->actionTemplate : $defaultActionTemplate;

            // assign all the "content" action's variables directly into the View's scope. This is
            // useful for variables that are required in the master template, like pageTitle.
            foreach($this->assignedVars as $name => $value)
            {
                $this->view->assign((string)$name, $value);
            }

        }
        // assign a template for this action into $templates->[action_name]. Note that by default
        // this is [controller_name]/[action_name].tpl.php
        $templates->$action = $this->actionTemplate ? $this->actionTemplate : $defaultActionTemplate;
        $this->view->assign('Templates', $templates);
    }

	// magic functions used so that any "invented" properties created in
	// the command functions get assigned to $assigned_vars and hence passed
	// to the view
	public function __get($name)
	{
		if(isset($this->assignedVars->$name))
		{
			return $this->assignedVars->$name;
		}
		return false;
	}

	public function __set($name, $value)
	{
		$this->assignedVars->$name = $value;
	}
}
?>